@@ -1,42 +1,20 @@
-/* Borrowed by Jonny Goldman. */
-/* $XConsortium: AsciiSrc.c,v 1.55 91/07/25 18:09:27 rws Exp $ */
-/*
- * $Log: myAsciiSrc.c,v $
- * Revision 2.0.1.6  1995/12/06 11:10:55  pfeifer
- * patch53: Added inclusion of "../ir/cdialect.h".
- *
- * Revision 2.0.1.5  1995/11/14  18:36:41  pfeifer
- * patch51:
- *
- * Revision 2.0.1.4  1995/10/20  17:10:22  pfeifer
- * patch40: Fixed the sys_errlist stuff (for the last time?).
- *
- * Revision 2.0.1.3  1995/10/10  19:03:49  pfeifer
- * patch35: Not all compilers know elseif :-(
- *
- * Revision 2.0.1.2  1995/10/06  07:27:02  pfeifer
- * patch22: Added sys_errlist hack for BSD.
- *
- * Revision 2.0.1.1  1995/09/15  09:56:50  pfeifer
- * patch7: Fixed CNIDR copyright line.
- *
- * Revision 2.0  1995/09/08  08:06:50  pfeifer
- * Metaconfig baseline
- *
- * Revision 1.4  1994/03/25  10:21:02  pfeifer
- * now will try to make 8-bit chars work
- *
- * Revision 1.2  93/07/01  18:19:07  warnock
- * Fixed declaration in MyAsciiSaveAsFile for SGI/X11R4
- * 
- * Revision 1.1  93/02/16  15:10:18  freewais
- * Initial revision
- * 
- * Revision 1.1  92/06/22  10:42:19  jonathan
- * Initial revision
+/*                               -*- Mode: C -*- 
+ * $Basename: myAsciiSrc.c $
+ * $Revision: 1.12.1.4 $
+ * Author          : XConsortium, borrowed by Jonny Goldman.
+ * Created On      : 91/07/25 18:09:27
+ * Last Modified By: Ulrich Pfeifer
+ * Last Modified On: Wed May  7 16:25:08 1997
+ * Language        : C
+ * Update Count    : 3
+ * Status          : Unknown, Use with caution!
  * 
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
  */
 
+/* $XConsortium: AsciiSrc.c,v 1.55 91/07/25 18:09:27 rws Exp $ */
+
 /*
  * Copyright 1989 Massachusetts Institute of Technology
  *
@@ -62,21 +40,18 @@
  * Much code taken from X11R3 String and Disk Sources.
  */
 
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
-
-
 /*
  * AsciiSrc.c - AsciiSrc object. (For use with the text widget).
  *
  */
 
+#include "cdialect.h"
 #include <X11/IntrinsicP.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <errno.h>
 #include <X11/StringDefs.h>
 #include <X11/Xos.h>
-/*#include <X11/Xfuncs.h>*/
 #include <X11/Xaw/XawInit.h>
 #include "myAsciiSrcP.h"
 #include <X11/Xmu/Misc.h>
@@ -140,7 +115,6 @@ static void ClassInitialize(), Initialize(), Destroy(), GetValuesHook();
 static String MyStrncpy(), StorePiecesInString();
 static Boolean SetValues(), WriteToFile();
 
-#include "../ir/cdialect.h"
 
 #ifdef HAS_SYS_ERRLIST
 #ifdef EXTERN_SYS_ERRLIST
